idq
===
iDigQuality Base Module

Production Setup
================

.. code-block::
    
    pip install idq

Development Setup
=================

.. code-block::

    git clone https://github.com/iDigBio/idq.git
    cd idq
    pip install -r requirements.txt
    python -m idq.example
